<?php
$translations = array(
	'General_Locale' => 'zh_TW.UTF-8',
	'General_TranslatorName' => '<a href="http://www.freegroup.org/">Pseric</a>, Eros',
	'General_TranslatorEmail' => 'pserics@gmail.com, php.twn@gmail.com',
	'General_EnglishLanguageName' => 'Traditional Chinese (Taiwan)',
	'General_OriginalLanguageName' => '繁體中文',
	'General_HelloUser' => '您好， %s！',
	'General_OpenSourceWebAnalytics' => '開放原始碼的網站流量分析軟體',
	'General_Dashboard' => '展示板',
	'General_DashboardForASpecificWebsite' => '特定網站展示板',
	'General_MultiSitesSummary' => '所有網站',
	'General_AllWebsitesDashboard' => '所有網站展示板',
	'General_Widgets' => '組件',
	'General_Settings' => '設定',
	'General_GiveUsYourFeedback' => '給我們反饋意見！',
	'General_Unknown' => '未知',
	'General_Required' => '%s 個請求',
	'General_NotValid' => '%s 無效',
	'General_Id' => 'ID',
	'General_Error' => '錯誤',
	'General_Warning' => '警告',
	'General_BackToHomepage' => '返回 Piwik 首頁',
	'General_Yes' => '是',
	'General_No' => '否',
	'General_Delete' => '刪除',
	'General_Report' => '回報',
	'General_Edit' => '編輯',
	'General_Download' => '下載',
	'General_Ok' => 'OK',
	'General_Close' => '關閉',
	'General_OrCancel' => '或 %s 取消 %s',
	'General_Logout' => '登出',
	'General_Username' => '使用者名稱',
	'General_Description' => '描述',
	'General_Done' => '完成',
	'General_Name' => '姓名',
	'General_Value' => '數值',
	'General_Details' => '詳情',
	'General_Default' => '預設',
	'General_Date' => '日期',
	'General_Period' => '期間',
	'General_Today' => '今天',
	'General_Yesterday' => '昨天',
	'General_CurrentWeek' => '本週',
	'General_CurrentMonth' => '本月',
	'General_CurrentYear' => '今年',
	'General_DateRange' => '日期範圍：',
	'General_LoadingData' => '載入資料中...',
	'General_Loading_js' => '載入中...',
	'General_GoTo' => '前往 %s',
	'General_Next' => '下一頁',
	'General_Previous' => '上一頁',
	'General_Search' => '搜尋',
	'General_Others' => '其他',
	'General_Table' => '表格',
	'General_Piechart' => '圓餅圖',
	'General_TagCloud' => '標籤雲',
	'General_VBarGraph' => '長條圖',
	'General_SaveImageOnYourComputer_js' => '將圖片儲存至您的電腦，在圖片上點選滑鼠右鍵然後選擇 "將圖片儲存為..."',
	'General_Refresh' => '重新整理網頁',
	'General_Visitors' => '訪客',
	'General_ExportThisReport' => '將此資料集匯出為其他格式',
	'General_ExportAsImage_js' => '匯出為圖片',
	'General_Export' => '匯出',
	'General_YourChangesHaveBeenSaved' => '您的變更已儲存！',
	'General_ErrorRequest' => '噢！請求期間發生問題，請重試！',
	'General_ColumnNbUniqVisitors' => '獨立非重返訪客數',
	'General_ColumnNbVisits' => '訪客',
	'General_ColumnPercentageVisits' => '% 個訪客',
	'General_ColumnNbActions' => '活動量',
	'General_ColumnMaxActions' => '單次造訪的最大活動量',
	'General_ColumnSumVisitLength' => '網站停留時間 (以秒為單位)',
	'General_ColumnLabel' => '標籤',
	'General_ColumnConversionRate' => '轉換率',
	'General_ColumnActionsPerVisit' => '各個造訪的活動量',
	'General_VisitDuration' => '平均訪問時間（以秒為單位）',
	'General_ColumnAvgTimeOnSite' => '平均網站停留時間',
	'General_ColumnBounceRate' => '跳出率',
	'General_ColumnExitRate' => '退出率',
	'General_ColumnPageviews' => '瀏覽量',
	'General_ColumnUniquePageviews' => '獨立非重返訪客瀏覽數',
	'General_ColumnBounces' => '跳出',
	'General_ColumnEntrances' => '主要到達網頁',
	'General_ColumnExits' => '主要離開網頁',
	'General_ColumnAverageTimeOnPage' => '平均網站停留時間',
	'General_ColumnValuePerVisit' => '每次造訪價值',
	'General_ColumnVisitsWithConversions' => '造訪轉換',
	'General_YearsDays' => '%1$s 年 %2$s 天',
	'General_DaysHours' => '%1$s 天 %2$s 小時',
	'General_HoursMinutes' => '%1$s 小時 %2$s 分',
	'General_MinutesSeconds' => '%1$s 分 %2$s 秒',
	'General_Seconds' => '%s 秒',
	'General_Save' => '儲存',
	'General_ForExampleShort' => '例如',
	'General_YouMustBeLoggedIn' => '您必須登入才能存取這個功能！',
	'General_Website' => '網站',
	'General_GeneralSettings' => '一般設定',
	'General_AllowPiwikArchivingToTriggerBrowser' => '當報告在瀏覽器裡檢視時，允許 Piwik 觸發彙整',
	'General_ArchivingInlineHelp' => '對於中或高流量的網站，建議停用 Piwik 彙整觸發瀏覽器。反之，我們建議你設定一個工作排程(Cron job)，每小時處理 Piwik 報告。',
	'General_ArchivingTriggerDescription' => '推薦大型的 Piwik 安裝，你需要%s設定一個工作排程(Cron job)%s來自動處理報告。',
	'General_SeeTheOfficialDocumentationForMoreInformation' => '查看%s官方文件%s取得更多資訊',
	'General_NSeconds' => '%s 秒處理一次',
	'General_SmallTrafficYouCanLeaveDefault' => '對於低流量的網站，你可以使用預設的 %s 秒，然後即時存取所有報告。',
	'General_MediumToHighTrafficItIsRecommendedTo' => '對於中或高流量的網站，我們建議最多每隔半小時(%s 秒)或每小時(%s 秒)處理報告。',
	'General_RequiresFlash' => '在 Piwik 顯示圖表必須有 Flash',
	'General_GraphHelp' => '更多關於 Piwik 顯示圖表的資訊',
	'General_NoDataForGraph' => '此圖表無任何資料。',
	'General_NoDataForTagCloud' => '此標籤雲無任何資料。',
	'General_DisplaySimpleTable' => '顯示簡易表格',
	'General_DisplayTableWithMoreMetrics' => '顯示更多數據表',
	'General_DisplayTableWithGoalMetrics' => '顯示目標數據表',
	'General_YouAreViewingDemoShortMessage' => '你正在瀏覽 Piwik 範例',
	'General_DownloadFullVersion' => '%1$s下載%2$s完整版本！來吧 %3$s',
	'General_NewUpdatePiwikX' => '新的更新：Piwik %s',
	'General_AboutPiwikX' => '關於 Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s 已經可用。 %2$s 請立即更新！%3$s （查看 %4$s 與%5$s 的差異）。',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s 已經可用。請通知網站管理員。',
	'General_NewReportsWillBeProcessedByCron' => '當 Piwik 存檔無法由瀏覽器觸發時，新的報表將以 crontab 處理。',
	'General_ReportsWillBeProcessedAtMostEveryHour' => '因此，報告最多每隔一小時將處理一次。',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => '假設在你的設定下存檔相當順暢，你可以設定並讓它的執行更頻繁。',
	'General_BackToPiwik' => '返回 Piwik',
	'General_ShortMonth_1' => '一月',
	'General_ShortMonth_2' => '二月',
	'General_ShortMonth_3' => '三月',
	'General_ShortMonth_4' => '四月',
	'General_ShortMonth_5' => '五月',
	'General_ShortMonth_6' => '六月',
	'General_ShortMonth_7' => '七月',
	'General_ShortMonth_8' => '八月',
	'General_ShortMonth_9' => '九月',
	'General_ShortMonth_10' => '十月',
	'General_ShortMonth_11' => '十一月',
	'General_ShortMonth_12' => '十二月',
	'General_LongMonth_1' => '一月',
	'General_LongMonth_2' => '二月',
	'General_LongMonth_3' => '三月',
	'General_LongMonth_4' => '四月',
	'General_LongMonth_5' => '五月',
	'General_LongMonth_6' => '六月',
	'General_LongMonth_7' => '七月',
	'General_LongMonth_8' => '八月',
	'General_LongMonth_9' => '九月',
	'General_LongMonth_10' => '十月',
	'General_LongMonth_11' => '十一月',
	'General_LongMonth_12' => '十二月',
	'General_ShortDay_1' => '週一',
	'General_ShortDay_2' => '週二',
	'General_ShortDay_3' => '週三',
	'General_ShortDay_4' => '週四',
	'General_ShortDay_5' => '週五',
	'General_ShortDay_6' => '週六',
	'General_ShortDay_7' => '週日',
	'General_LongDay_1' => '星期一',
	'General_LongDay_2' => '星期二',
	'General_LongDay_3' => '星期三',
	'General_LongDay_4' => '星期四',
	'General_LongDay_5' => '星期五',
	'General_LongDay_6' => '星期六',
	'General_LongDay_7' => '星期日',
	'General_Daily' => '每天',
	'General_Weekly' => '每週',
	'General_Monthly' => '每月',
	'General_ConfigFileIsNotWritable' => 'Piwik 設定檔 %s 無法寫入，你的變更將無法儲存。%s 請變更設定檔權限讓它可被寫入。',
	'General_ExceptionDatabaseVersion' => '你的 %1$s 版本為 %2$s ，但 Piwik 需求至少要 %3$s。',
	'General_ExceptionIncompatibleClientServerVersions' => '你的 %1$s 客戶端版本為 %2$s，與伺服器版本 %3$s 不相容。',
	'General_ExceptionMissingFile' => '遺失檔案: %s',
	'General_ExceptionFilesizeMismatch' => '檔案大小不符: %1$s （預計長度: %2$s, 找到: %3$s）',
	'General_ExceptionFileIntegrity' => '完整性檢查失敗: %s',
	'General_ExceptionNonceMismatch' => '無法驗證此表單的安全性。',
	'General_PleaseSpecifyValue' => '請為 \'%s\' 設定一個數值。',
	'General_ExceptionMethodNotFound' => '\'%s\' 不存在或不適用於模組 \'%s\' 裡。',
	'General_ExceptionInvalidRendererFormat' => '\'%s\' 是不合法的。嘗試以下任一來取代: %s 。',
	'General_ExceptionInvalidPeriod' => '目前不支援 \'%s\' 。嘗試以下任一來取代: %s',
	'General_ExceptionInvalidDateRange' => '\'%s\' 不是一個正確的日期範圍。它應該擁有以下格式: %s。',
	'General_ExceptionGoalNotFound' => '目標 id = %s 找不到。',
	'General_ExceptionUndeletableFile' => '無法刪除 %s',
	'General_ExceptionPrivilege' => '你無法存取這個資源，必須要一個 %s 權限。',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => '你無法存取這個資源，必須至少要一個網站的 %s 權限。',
	'General_ExceptionPrivilegeAccessWebsite' => '你無法存取這個資源，必須擁有網站 ID = %d 的 %s 權限。',
	'General_ExceptionInvalidArchiveTimeToLive' => '今日彙整時間必須是一個大於 0 秒的數字',
	'General_ExceptionConfigurationFileNotFound' => '設定檔 {%s} 找不到。',
	'General_ExceptionUnreadableFileDisabledMethod' => '設定檔 {%s} 無法讀取。你的主機空間可能停用 %s。',
	'General_ExceptionInvalidToken' => '符號不合法。',
	'General_ExceptionInvalidDateFormat' => '日期格式必須為: %s 或任何被 %s 函式支援的關鍵字（查看 %s 取得更多資訊）',
	'General_ExceptionLanguageFileNotFound' => '語系檔案 \'%s\' 找不到。',
	'General_WarningFileIntegritySkipped' => '檢測到開發環境。跳過檔案完整性檢查。',
	'General_WarningFileIntegrityNoManifest' => '缺少 manifest.inc.php 所以檔案完整性檢查無法執行。',
	'General_WarningFileIntegrityNoMd5file' => '缺少 md5_file() 函式所以檔案完整性檢查無法玩成。',
	'General_FileIntegrityWarningExplanation' => '檔案完整性檢查錯誤且回報了一些問題。這大多是因為上傳了部分或錯誤的 Piwik 檔案所致。你應該使用 BINARY 模式重新上傳所有的 Piwik 檔案然後重新整理此頁面直到它沒有顯示任何錯誤。',
	'General_UseSMTPServerForEmail' => '使用 SMTP 伺服器來傳送 E-mail',
	'General_SmtpServerAddress' => 'SMTP 伺服器位址',
	'General_SmtpPort' => 'SMTP 通訊埠',
	'General_AuthenticationMethodSmtp' => 'SMTP 驗證方法',
	'General_SmtpUsername' => 'SMTP 使用者名稱',
	'General_SmtpPassword' => 'SMTP 密碼',
	'General_SmtpEncryption' => 'SMTP 加密',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => '如果你想透過一個 named server 來寄送電子郵件，而不是 mail 函式的話請選擇 "Yes"',
	'General_OnlyUsedIfUserPwdIsSet' => '只在使用者名稱 / 密碼設定後才會生效，如果你不確定要使用何種方法，請詢問你的提供商。',
	'General_OnlyEnterIfRequired' => '只在你的 SMTP 伺服器需要使用者名稱時才需要輸入',
	'General_OnlyEnterIfRequiredPassword' => '只在你的 SMTP 伺服器需要密碼時才需要輸入',
	'General_WarningPasswordStored' => '%s警告:%s 此密碼將被儲存在設定檔中，且每個能存取它的人都看得到。',
	'General_InvalidResponse' => '接收到的資料是無效的。',
	'General_ChooseLanguage' => '選擇語系',
	'General_ChoosePeriod' => '選擇期間',
	'General_ChooseWebsite' => '選擇網站',
	'General_Language' => '語系',
	'General_PleaseUpdatePiwik' => '請更新您的 Piwik',
	'General_RequestTimedOut' => '%s 資料請求逾時，請再試一次。',
	'Actions_PluginDescription' => '關於頁面瀏覽量、離開連結和下載。離開連結及下載的追蹤是自動的！',
	'Actions_Actions' => '進站活動',
	'Actions_SubmenuPages' => '瀏覽頁面',
	'Actions_SubmenuPagesEntry' => '到達網頁',
	'Actions_SubmenuPagesExit' => '離開網頁',
	'Actions_SubmenuPageTitles' => '網頁標題',
	'Actions_SubmenuOutlinks' => '離開連結',
	'Actions_SubmenuDownloads' => '下載',
	'Actions_ColumnClicks' => '點擊次數',
	'Actions_ColumnUniqueClicks' => '絕對不重複點擊次數',
	'Actions_ColumnDownloads' => '下載次數',
	'Actions_ColumnUniqueDownloads' => '絕對不重複下載次數',
	'Actions_ColumnPageName' => '頁面名稱',
	'Actions_ColumnPageURL' => '頁面網址',
	'Actions_ColumnClickedURL' => '點擊的 URL 位址',
	'Actions_ColumnDownloadURL' => '下載的 URL 位址',
	'AnonymizeIP_PluginDescription' => '隱藏訪客IP位址最後一個字元以符合你的當地隱私條例/政策。',
	'API_PluginDescription' => '所有在 Piwik 的資料都能使用簡單的 APIs 取得。這個外掛是網頁服務的切入點，讓你可以以 xml, json, php, csv 及其他格式取得網站分析資料。',
	'API_QuickDocumentationTitle' => 'API 快速說明文件',
	'API_GenerateVisits' => '如果你今天還沒有任何資料，你可以先使用 %s 外掛來產生一些數據。你可以啟用 %s 外掛，然後點擊在 Piwik 管理員區域裡的\'產生訪客\'選單。',
	'API_MoreInformation' => '取得更多關於 Piwik APIs 的資訊，請前往 %sPiwik API 指引%s 與 %s Piwik API 參考資料%s。',
	'API_UserAuthentication' => '使用者驗證',
	'API_UsingTokenAuth' => '如果你想從程式、工作排程在 %s 請求資料。%s 你需要新增一個 %s 字串至 API 呼叫網址來進行驗證。',
	'API_KeepTokenSecret' => 'token_auth 如你的帳號和密碼般重要，%s請不要公開它%s！',
	'API_LoadedAPIs' => '已成功載入 %s 個 APIs',
	'CoreAdminHome_PluginDescription' => 'Piwik 管理區域',
	'CoreAdminHome_MenuGeneralSettings' => '一般設定',
	'CoreAdminHome_Administration' => '管理',
	'CoreHome_PluginDescription' => '網站分析報告結構。',
	'CoreHome_WebAnalyticsReports' => '網站分析報告',
	'CoreHome_JavascriptDisabled' => '使用 Piwik 的標準檢視時必須啟用 JavaScript。<br />然而，看來你的瀏覽器已停用或不支援 JavaScript。<br />若要使用標準檢視，請變更你的瀏覽器選項並啟用 JavaScript, 然後%1$s重試一次%2$s。<br />',
	'CoreHome_ThereIsNoDataForThisReport' => '此報告項目無資料！',
	'CoreHome_CategoryNoData' => '無資料在此類別！ 嘗試使用 "包含所有個體"！',
	'CoreHome_ShowJSCode' => '顯示 JavaScript 追蹤碼以供插入',
	'CoreHome_PageOf_js' => '%1$s 之於 %2$s',
	'CoreHome_PeriodDay' => '日統計',
	'CoreHome_PeriodWeek' => '週統計',
	'CoreHome_PeriodMonth' => '月統計',
	'CoreHome_PeriodYear' => '年統計',
	'CoreHome_PeriodDays' => '天',
	'CoreHome_PeriodWeeks' => '週',
	'CoreHome_PeriodMonths' => '月',
	'CoreHome_PeriodYears' => '年',
	'CoreHome_DaySu_js' => '日',
	'CoreHome_DayMo_js' => '一',
	'CoreHome_DayTu_js' => '二',
	'CoreHome_DayWe_js' => '三',
	'CoreHome_DayTh_js' => '四',
	'CoreHome_DayFr_js' => '五',
	'CoreHome_DaySa_js' => '六',
	'CoreHome_ShortDay_1_js' => '周日',
	'CoreHome_ShortDay_2_js' => '周一',
	'CoreHome_ShortDay_3_js' => '周二',
	'CoreHome_ShortDay_4_js' => '周三',
	'CoreHome_ShortDay_5_js' => '周四',
	'CoreHome_ShortDay_6_js' => '周五',
	'CoreHome_ShortDay_7_js' => '周六',
	'CoreHome_LongDay_1_js' => '星期日',
	'CoreHome_LongDay_2_js' => '星期一',
	'CoreHome_LongDay_3_js' => '星期二',
	'CoreHome_LongDay_4_js' => '星期三',
	'CoreHome_LongDay_5_js' => '星期四',
	'CoreHome_LongDay_6_js' => '星期五',
	'CoreHome_LongDay_7_js' => '星期六',
	'CoreHome_ShortMonth_1_js' => '一',
	'CoreHome_ShortMonth_2_js' => '二',
	'CoreHome_ShortMonth_3_js' => '三',
	'CoreHome_ShortMonth_4_js' => '四',
	'CoreHome_ShortMonth_5_js' => '五',
	'CoreHome_ShortMonth_6_js' => '六',
	'CoreHome_ShortMonth_7_js' => '七',
	'CoreHome_ShortMonth_8_js' => '八',
	'CoreHome_ShortMonth_9_js' => '九',
	'CoreHome_ShortMonth_10_js' => '十',
	'CoreHome_ShortMonth_11_js' => '十一',
	'CoreHome_ShortMonth_12_js' => '十二',
	'CoreHome_MonthJanuary_js' => '一月',
	'CoreHome_MonthFebruary_js' => '二月',
	'CoreHome_MonthMarch_js' => '三月',
	'CoreHome_MonthApril_js' => '四月',
	'CoreHome_MonthMay_js' => '五月',
	'CoreHome_MonthJune_js' => '六月',
	'CoreHome_MonthJuly_js' => '七月',
	'CoreHome_MonthAugust_js' => '八月',
	'CoreHome_MonthSeptember_js' => '九月',
	'CoreHome_MonthOctober_js' => '十月',
	'CoreHome_MonthNovember_js' => '十一月',
	'CoreHome_MonthDecember_js' => '十二月',
	'CorePluginsAdmin_PluginDescription' => '外掛管理介面。',
	'CorePluginsAdmin_Plugins' => '外掛',
	'CorePluginsAdmin_PluginsManagement' => '外掛管理',
	'CorePluginsAdmin_MainDescription' => '外掛延伸並擴展了 Piwik 的功能。 當一個外掛安裝了以後，您可以在這裏啟用或停用它。',
	'CorePluginsAdmin_Plugin' => '外掛',
	'CorePluginsAdmin_Version' => '版本',
	'CorePluginsAdmin_Status' => '狀態',
	'CorePluginsAdmin_Action' => '動作',
	'CorePluginsAdmin_PluginHomepage' => '外掛首頁',
	'CorePluginsAdmin_Activated' => '已作用中',
	'CorePluginsAdmin_Active' => '啟用中',
	'CorePluginsAdmin_Inactive' => '停用中',
	'CorePluginsAdmin_Deactivate' => '停用',
	'CorePluginsAdmin_Activate' => '啟用',
	'CorePluginsAdmin_MenuPlugins' => '外掛',
	'CoreUpdater_PluginDescription' => 'Piwik 更新機制',
	'CoreUpdater_UpdateTitle' => 'Piwik › 更新',
	'CoreUpdater_DatabaseUpgradeRequired' => '資料庫需要升級',
	'CoreUpdater_YourDatabaseIsOutOfDate' => '你的 Piwik 資料庫已經過期了，所以在繼續前必須先升級。',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik 資料庫將從版本 %1$s 升級至新版本 %2$s 。',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => '以下外掛將被更新：%s 。',
	'CoreUpdater_NoteForLargePiwikInstances' => '大型 Piwik 網站重要注意事項',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => '如果你有一個大型的 Piwik 資料庫，在瀏覽器內更新可能需要花費很長時間。在此情況下，你可以透過以下指令來執行更新：%s',
	'CoreUpdater_YouCouldManuallyExecuteSqlQueries' => '如果你無法使用指令列更新且 Piwik 升級失敗（資料庫超時、瀏覽器超時或任何問題），你可以手動執行 SQL 語法來更新 Piwik.',
	'CoreUpdater_ClickHereToViewSqlQueries' => '點選這裡來查看並複製即將執行的 SQL 語法列表',
	'CoreUpdater_NoteItIsExpectedThatQueriesFail' => '注意：如果你手動執行這些查詢，預計當中會有一些錯誤。在此情況下，只需忽略錯誤，然後執行以下列表。',
	'CoreUpdater_ReadyToGo' => '準備好了嗎？',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => '資料庫升級過程可能需要一段時間，所以請耐心等待。',
	'CoreUpdater_UpgradePiwik' => '升級 Piwik',
	'CoreUpdater_ErrorDIYHelp' => '如果你是進階用戶且在升級資料庫時發生錯誤：',
	'CoreUpdater_ErrorDIYHelp_1' => '辨識並修正問題來源（例如 memory_limit 或 max_execution_time）',
	'CoreUpdater_ErrorDIYHelp_2' => '執行升級失敗時剩餘的 SQL 語法',
	'CoreUpdater_ErrorDIYHelp_3' => '手動更新你的 Piwik 資料庫內的 \'option\' 資料表，version_core 的設定值更新失敗',
	'CoreUpdater_ErrorDIYHelp_4' => '重新執行更新程式（透過瀏覽器或指令列）來繼續剩餘的更新',
	'CoreUpdater_ErrorDIYHelp_5' => '回報問題（或解決辦法）以改善 Piwik',
	'CoreUpdater_HelpMessageContent' => '請檢查 %1$s Piwik FAQ %2$s，其中已有更新過程中所發生的常見錯誤之解決辦法。%3$s 詢問你的系統管理員 - 他們應該可以協助你解決大部分關於伺服器或 MySQL 設定的問題。',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => '在更新過程中發生嚴重的錯誤：',
	'CoreUpdater_HelpMessageIntroductionWhenError' => '以上是核心錯誤訊息。它應該有助於解釋原因，但如果你需要進一步的說明請至：',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => '此次更新成功完成，但在過程中有發生一些問題。請閱讀以上說明的詳細內容。如需更進一步的說明：',
	'CoreUpdater_UpgradeComplete' => '升級完成！',
	'CoreUpdater_WarningMessages' => '警告訊息：',
	'CoreUpdater_ErrorDuringPluginsUpdates' => '外掛升級期間發生錯誤：',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => '我們自動停用了以下的外掛： %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik 已成功更新！',
	'CoreUpdater_ContinueToPiwik' => '繼續 Piwik',
	'CoreUpdater_UpdateAutomatically' => '自動更新',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => '已有一個新版的 Piwik 可供更新',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => '你可以自動更新至版本 %s ，或是下載壓縮檔並手動安裝它：',
	'CoreUpdater_YouMustDownloadPackageOrFixPermissions' => 'Piwik 無法覆寫你當前的安裝。你可以直接修改目錄/檔案權限，或是下載壓縮檔然後手動安裝 %s 版本：',
	'CoreUpdater_DownloadX' => '下載 %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik 一鍵更新已被取消。如果你無法修正以上的錯誤訊息，建議你手動更新 Piwik。%1$s 請查看 %2$s更新文件%3$s 來開始吧！',
	'CoreUpdater_DownloadingUpdateFromX' => '從 %s 下載更新中',
	'CoreUpdater_UnpackingTheUpdate' => '正在解壓縮更新',
	'CoreUpdater_VerifyingUnpackedFiles' => '正在驗證解壓縮後的檔案',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => '建立一個設定檔的備份於 %s',
	'CoreUpdater_InstallingTheLatestVersion' => '正在安裝最新版本中',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik 已成功更新！',
	'CoreUpdater_EmptyDatabaseError' => '資料庫 %s 是空的。你可能要編輯或移除你的 Piwik 設定檔。',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => '你的 Piwik 版本 %s 是最新的。',
	'CoreUpdater_ExceptionArchiveIncompatible' => '不相容的檔案： %s',
	'CoreUpdater_ExceptionArchiveEmpty' => '空的檔案。',
	'CoreUpdater_ExceptionArchiveIncomplete' => '檔案是不完整的：遺失某些檔案（例如 %s）。',
	'Dashboard_PluginDescription' => '你的網站分析控制台。你可以自動你的控制台：新增新的模組、變更你的模組排序。每位使用者可以存取他們自訂的控制台。',
	'Dashboard_Dashboard' => '展示板',
	'Dashboard_DeleteWidgetConfirm' => '您確定要從展示板中刪除此組件嗎？',
	'Dashboard_SelectWidget' => '請選取欲增加至展示板的組件',
	'Dashboard_AddPreviewedWidget_js' => '增加已預覽的組件至展示板',
	'Dashboard_WidgetPreview_js' => '組件預覽',
	'Dashboard_Close_js' => '關閉',
	'Dashboard_TitleWidgetInDashboard_js' => '組件已存在於展示板',
	'Dashboard_TitleClickToAdd_js' => '點擊以增加至展示板',
	'Dashboard_LoadingWidget_js' => '載入組件中，請稍候...',
	'Dashboard_WidgetNotFound_js' => '找不到組件',
	'DBStats_PluginDescription' => '這個外掛能回報 Piwik 的資料表使用情形。',
	'DBStats_DatabaseUsage' => '資料庫使用狀況',
	'DBStats_MainDescription' => 'Piwik 儲存所有你的網站分析資料於 MySQL 資料庫中。目前， Piwik 資料表已經使用了 %s。',
	'DBStats_LearnMore' => '瞭解更多關於 Piwik 如何處理數據以及使 Piwik 在中高流量的網站上運作得宜，請查閱說明文件 %s。',
	'DBStats_Table' => '資料表',
	'DBStats_RowCount' => '資料列計數',
	'DBStats_DataSize' => '資料大小',
	'DBStats_IndexSize' => '索引大小',
	'DBStats_TotalSize' => '總容量',
	'ExampleAPI_PluginDescription' => '範例外掛：如何為你的外掛建立一個 API, 然後將多種格式的資料匯出且無須任何原始碼？',
	'ExampleRssWidget_PluginDescription' => '範例外掛：如何建立一個新組件來讀取 RSS feed？',
	'ExampleUI_PluginDescription' => '範例外掛：這個外掛讓你瞭解如何使 Piwik UI 運作：建立資料表、圖表等等。',
	'Feedback_PluginDescription' => '傳送你的意見反應給 Piwik 小組。與我們分享你的點子及建議！',
	'Feedback_DoYouHaveBugReportOrFeatureRequest' => '你有一個臭蟲回報或功能請求？',
	'Feedback_ViewAnswersToFAQ' => '至 %s常見問題%s 找尋答案',
	'Feedback_WhyAreMyVisitsNoTracked' => '為什麼我的訪問沒有被追蹤？',
	'Feedback_HowToExclude' => '如何排除追蹤我的訪問紀錄？',
	'Feedback_WhyWrongCountry' => '為什麼 Piwik 顯示了錯誤的來源國家？',
	'Feedback_HowToAnonymizeIP' => '如合在我的資料庫裡屏障訪客的 IP 位址？',
	'Feedback_VisitTheForums' => '訪問 %s 論壇%s',
	'Feedback_LearnWaysToParticipate' => '瞭解所有你可以 %s 參與%s 的方法',
	'Feedback_SpecialRequest' => '你對於 Piwik 小組有特殊的請求？',
	'Feedback_ContactThePiwikTeam' => '聯絡 Piwik 團隊！',
	'Feedback_IWantTo' => '我想要：',
	'Feedback_CategoryShareStory' => '分享一個 Piwik 成功故事',
	'Feedback_CategorySponsor' => '贊助 Piwik',
	'Feedback_CategoryHire' => '雇用一位 Piwik 顧問',
	'Feedback_CategorySecurity' => '回報一個安全性問題',
	'Feedback_MyEmailAddress' => '我的 Email 地址：',
	'Feedback_MyMessage' => '我的訊息：',
	'Feedback_DetailsPlease' => '（請包含細節）',
	'Feedback_SendFeedback' => '送出意見',
	'Feedback_ManuallySendEmailTo' => '請手動寄送你的訊息至',
	'Feedback_MessageSent' => '你的訊息已寄給 Piwik 小組。',
	'Feedback_ThankYou' => '謝謝你協助我們使 Piwik 變得更好！',
	'Feedback_ThePiwikTeam' => 'Piwik 小組',
	'Feedback_ExceptionBodyLength' => '訊息至少要有 %s 的字元以上。',
	'Feedback_ExceptionNoUrls' => '訊息不能包含一個網址，藉此避免垃圾訊息。',
	'Goals_Goals' => '目標',
	'Goals_GoalsOverview' => '目標總覽',
	'Goals_GoalsManagement' => '目標管理',
	'Goals_PluginDescription' => '建立目標然後查看關於你的目標轉換率報表：時間的演變趨勢、每次訪問的收入、每個關鍵字等等。',
	'Goals_ColumnConversions' => '轉換',
	'Goals_ColumnRevenue' => '收益',
	'Goals_GoalX' => '目標 %s',
	'Goals_OverallRevenue' => '%s 總收益',
	'Goals_OverallConversionRate' => '%s 總轉換率（訪問一個完整的目標）',
	'Goals_Conversions' => '%s 轉換數',
	'Goals_ConversionRate' => '%s 轉換率',
	'Goals_NoGoalsNeedAccess' => '只有管理員或超級使用者能為網站新增目標。請詢問你的 Piwik 管理員來協助設定你的網站目標。<br />追蹤目標是一個絕佳的方式，幫忙瞭解及最大化你的網站效益！',
	'Goals_AddNewGoal' => '新增一個新的目標',
	'Goals_AddNewGoalOrEditExistingGoal' => '%s新增一個新的目標%s 或 %s編輯%s 已存在的目標',
	'Goals_AddGoal_js' => '新增目標',
	'Goals_UpdateGoal_js' => '更新目標',
	'Goals_DeleteGoalConfirm_js' => '你確定要刪除目標 %s ？',
	'Goals_CreateNewGOal' => '建立一個新的目標',
	'Goals_ViewAndEditGoals' => '檢視和編輯目標',
	'Goals_GoalName' => '目標名稱',
	'Goals_GoalIsTriggered' => '目標觸發',
	'Goals_GoalIsTriggeredWhen' => '目標觸發當',
	'Goals_WhenVisitors' => '當訪客',
	'Goals_WhereThe' => '位於',
	'Goals_Manually' => '手動',
	'Goals_ManuallyTriggeredUsingJavascriptFunction' => '手動觸發的目標是使用 JavaScript API trackGoal()',
	'Goals_VisitUrl' => '訪問特定網址（頁面或頁面群組）',
	'Goals_URL' => '網址',
	'Goals_Filename' => '檔案名稱',
	'Goals_ExternalWebsiteUrl' => '外部網站網址',
	'Goals_Download' => '下載一個檔案',
	'Goals_ClickOutlink' => '點選一個連結到外部網站',
	'Goals_Optional' => '（選用）',
	'Goals_WhereVisitedPageManuallyCallsJavascriptTrackerLearnMore' => '在被訪問的頁面包含一個 JavaScript piwikTracker.trackGoal() 方法（%s知道更多%s）',
	'Goals_DefaultRevenue' => '目標預設收益是',
	'Goals_DefaultRevenueHelp' => '舉例來說，訪客送出一個聯繫表單可能平均價值為 $10。Piwik 將幫助你瞭解你的訪客。',
	'Goals_ConversionsOverview' => '轉換總覽',
	'Goals_BestCountries' => '你的最佳轉換國家為：',
	'Goals_BestKeywords' => '你的最佳轉換關鍵字為：',
	'Goals_BestReferers' => '你的最佳轉換網站推薦連結為：',
	'Goals_ReturningVisitorsConversionRateIs' => '回訪訪客轉換率為 %s',
	'Goals_NewVisitorsConversionRateIs' => '新訪客轉換率為 %s',
	'Goals_Contains' => '有 %s',
	'Goals_IsExactly' => '正是 %s',
	'Goals_MatchesExpression' => '表達式符合 %s',
	'Goals_CaseSensitive' => '大小寫符合',
	'Goals_Pattern' => '模式',
	'Goals_ExceptionInvalidMatchingString' => '如果你選擇 \'精準符合\'，相符的字串必須包含一個網址開頭 %s. 舉例來說，\'%s\' 。',
	'Goals_LearnMoreAboutGoalTrackingDocumentation' => '在使用者文件裡找到更多關於 %s Piwik 裡的追蹤目標 %s。',
	'Installation_PluginDescription' => 'Piwik 的安裝程式。通常只需要安裝一次。如果設定檔 config/config.inc.php 被刪除，那麼將會重新安裝。',
	'Installation_Installation' => '安裝',
	'Installation_InstallationStatus' => '安裝狀態',
	'Installation_PercentDone' => '%s %% 已完成',
	'Installation_NoConfigFound' => '無法找到 Piwik 設定檔，而你正嘗試存取一個 Piwik 的頁面。<br /><b>  » 你可以 <a href=\'index.php\'>立刻安裝 Piwik</a></b><br /><small>假如你之前已安裝過 Piwik，並且已有些資料表在你的資料庫中，不用擔心，你可以重複使用此相同的資料表並保留現存的資料！</small>',
	'Installation_DatabaseSetup' => '資料庫設定',
	'Installation_DatabaseSetupServer' => '資料庫伺服器',
	'Installation_DatabaseSetupLogin' => '資料庫帳號',
	'Installation_DatabaseSetupPassword' => '資料庫密碼',
	'Installation_DatabaseSetupDatabaseName' => '資料庫名稱',
	'Installation_DatabaseSetupTablePrefix' => '資料表前綴詞',
	'Installation_DatabaseSetupAdapter' => 'Adapter',
	'Installation_DatabaseErrorConnect' => '連線至資料庫伺服器時發生錯誤',
	'Installation_DatabaseCheck' => '資料庫檢查',
	'Installation_DatabaseServerVersion' => '資料庫伺服器版本',
	'Installation_DatabaseClientVersion' => '資料庫客戶端版本',
	'Installation_DatabaseCreation' => '資料庫建立',
	'Installation_PleaseFixTheFollowingErrors' => '請修復以下錯誤',
	'Installation_LargePiwikInstances' => 'Piwik 給予大型網站的協助',
	'Installation_JsTag' => 'JavaScript 原始碼',
	'Installation_JsTagArchivingHelp' => '在一個中或高流量的網站，請查閱<a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">如何設定自動彙整頁面</a>來使 Piwik 運作的更順暢！',
	'Installation_Congratulations' => '恭喜你',
	'Installation_CongratulationsHelp' => '<p>恭喜！ 你的 Piwik 安裝已經完成。</p><p>請確認你的 JavaScript 追蹤碼已插入至你的網頁中，然後等候你的首位訪客吧！</p>',
	'Installation_ContinueToPiwik' => '繼續 Piwik',
	'Installation_SetupWebsite' => '設定一個網站',
	'Installation_SetupWebSiteName' => '網站名稱',
	'Installation_SetupWebSiteURL' => '網站網址',
	'Installation_Timezone' => '網站時區',
	'Installation_SetupWebsiteError' => '當增加此網站時發生了一個錯誤',
	'Installation_SetupWebsiteSetupSuccess' => '網站 %s 已成功建立！',
	'Installation_SuperUserLogin' => '超級使用者帳號',
	'Installation_Password' => '密碼',
	'Installation_PasswordRepeat' => '密碼 （再輸入一次確認）',
	'Installation_Email' => 'E-mail',
	'Installation_SecurityNewsletter' => '寄給我重要的 Piwik 更新與安全性警告電子郵件通知',
	'Installation_CommunityNewsletter' => '寄給我社群更新的電子郵件通知（如：新外掛、新功能等等。）',
	'Installation_PasswordDoNotMatch' => '密碼不相符',
	'Installation_Requirements' => 'Piwik 需求',
	'Installation_Optional' => '選擇性',
	'Installation_Legend' => '說明',
	'Installation_Extension' => '擴充',
	'Installation_SystemCheck' => '系統檢查',
	'Installation_SystemCheckPhp' => 'PHP 版本',
	'Installation_SystemCheckExtensions' => '其他需要的擴充元件',
	'Installation_SystemCheckDatabaseHelp' => 'Piwik 需要 mysqli 擴充元件或包含 PDO 及 pdo_mysql 擴充元件。',
	'Installation_SystemCheckPdoAndMysqliHelp' => '在 Linux 伺服器上你可以使用以下選項編譯 PHP: 在你的php.ini 中 %1$s, 加入以下幾行: %2$s',
	'Installation_SystemCheckPhpPdoAndMysqliSite' => '更多資訊：<a style="color:red" href="http://php.net/pdo">PHP PDO</a> 和 <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
	'Installation_SystemCheckWinPdoAndMysqliHelp' => '在 Windows 伺服器上你可以新增以下幾行至你的 php.ini 中: %s',
	'Installation_SystemCheckSplHelp' => '你需要設定及重建 PHP, 然後啟用 Standard PHP Library (SPL)。',
	'Installation_SystemCheckZlibHelp' => '你需要設定及重建 PHP, 然後啟用"zlib"支援, --with-zlib.',
	'Installation_SystemCheckIconvHelp' => '你需要設定及重建 PHP, 然後啟用"iconv"支援, --with-iconv.',
	'Installation_SystemCheckWriteDirs' => '具寫入存取權限的目錄',
	'Installation_SystemCheckWriteDirsHelp' => '要在你的 Linux 系統修正這個錯誤，嘗試輸入以下指令',
	'Installation_SystemCheckMemoryLimit' => '記憶體限制',
	'Installation_SystemCheckMemoryLimitHelp' => '在一個高流量的網站，資料彙整歸檔過程可能超過目前所允許使用的記憶體量。<br />假如必要，試著變更在你的 php.ini 檔案裡的 memory_limit.',
	'Installation_SystemCheckOpenURL' => '開啟網址',
	'Installation_SystemCheckOpenURLHelp' => '新聞訂閱、更新通知及一鍵安裝更新功能需要 "curl" 函式，allow_url_fopen=On, 或啟用 fsockopen().',
	'Installation_SystemCheckGD' => 'GD > 2.x (繪圖函式庫)',
	'Installation_SystemCheckGDHelp' => 'Sparklines (小圖) 將無法運作。',
	'Installation_SystemCheckFunctions' => '必須函式',
	'Installation_SystemCheckTimeLimitHelp' => '在一個高流量的網站，執行資料彙整歸檔過程可能超過目前所允許使用的時間。<br />假如必要，試著變更在你的 php.ini 檔案裡的 max_execution_time.',
	'Installation_SystemCheckMailHelp' => '意見回應及忘記密碼訊息若沒有 mail() 將無法寄送。',
	'Installation_SystemCheckParseIniFileHelp' => '內建的函式在你的空間內已被停用。Piwik 將會嘗試模擬這些功能，但可能會造成更多安全性問題。追蹤的表現也會受到影響。',
	'Installation_SystemCheckGlobHelp' => '這個內建的函式已被你的主機商停用。Piwik 將嘗試模擬這個功能，但可能會遇到更多安全限制。功能可能受到影響。',
	'Installation_SystemCheckDebugBacktraceHelp' => '檢視::無法建立模組檢視。',
	'Installation_SystemCheckCreateFunctionHelp' => 'Piwik 在callbacks上使用匿名函式。',
	'Installation_SystemCheckEvalHelp' => '必須為 HTML QuickForm 及 Smarty 模版系統。',
	'Installation_SystemCheckMbstringFuncOverloadHelp' => '你應該將 mbstring.func_overload 設定為 "0"。',
	'Installation_SystemCheckFileIntegrity' => '檔案完整性',
	'Installation_SystemCheckAutoUpdateHelp' => '注意：Piwik 的一鍵更新功能必須要有 Piwik 目錄及內容的寫入權限。',
	'Installation_SystemCheckError' => '發生錯誤 - 繼續前必須先修正',
	'Installation_SystemCheckWarning' => 'Piwik 能正常運作，但部份功能可能會失效',
	'Installation_Tables' => '建立資料表中',
	'Installation_TablesWithSameNamesFound' => '部份 %1$s 資料表在你的資料庫 %2$s 與 Piwik 正嘗試建立的資料表名稱重複',
	'Installation_TablesFound' => '以下的資料表在資料庫之中被找到',
	'Installation_TablesWarningHelp' => '選擇重複使用現存的資料表或者選擇全新安裝，以清除所有現存資料庫中的資料。',
	'Installation_TablesReuse' => '重複使用已存在的資料表',
	'Installation_TablesDelete' => '刪除已檢測到的資料表',
	'Installation_TablesDeletedSuccess' => '已存在的 Piwik 資料表已成功刪除',
	'Installation_TablesCreatedSuccess' => '資料表已成功建立！',
	'Installation_DatabaseCreatedSuccess' => '資料庫 %s 已成功建立！',
	'Installation_GoBackAndDefinePrefix' => '返回並為 Piwik 資料表定義一個資料表前綴',
	'Installation_ConfirmDeleteExistingTables' => '你確定要從你的資料庫刪除資料表 %s 嗎？ 警告： 這些資料表刪除後將無法復原！',
	'Installation_Welcome' => '歡迎使用！',
	'Installation_WelcomeHelp' => '<p>Piwik 是一個能夠讓你輕而易舉就取得訪客資訊的開放原始碼網站分析軟體。</p><p>此安裝過程分為 %s 個簡易的步驟，需要大約 5 分鐘的時間。</p>',
	'Installation_ConfigurationHelp' => '你的 Piwik 設定檔看起來似乎損毀了。你可以移除 config/config.ini.php 然後重新安裝，或是修正資料庫的連結設定。',
	'Installation_ErrorInvalidState' => '錯誤：看來你正在嘗試停止安裝程序的某個步驟，或是您的 cookies 功能未啟用，或者 Piwik 設定檔已經建立。%1$s請確定您的 cookies 功能已啟用%2$s然後返回%3$s至安裝程序的初始畫面 %4$s。',
	'LanguagesManager_PluginDescription' => '這個外掛會顯示 Piwik 介面可以使用的語系列表。選擇的語言將會被保存在每個使用者的偏好裡。',
	'LanguagesManager_AboutPiwikTranslations' => '關於 Piwik 翻譯',
	'Live_PluginDescription' => '窺視你的訪客，即時！',
	'Live_LinkVisitorLog' => '查看詳細的訪客記錄',
	'Live_Actions' => '動作',
	'Live_Action' => '動作',
	'Live_VisitorLog' => '訪客記錄',
	'Live_Time' => '時間',
	'Live_Referrer_URL' => '推薦連結',
	'Login_PluginDescription' => '登入驗證外掛，超級使用者從 config/config.inc.php 檔案讀取憑證，其他使用者則從資料庫。可以很容易取代或導入新的驗證機制（OpenID, htaccess, 自訂驗證等等）。',
	'Login_LoginPasswordNotCorrect' => '使用者名稱 & 密碼不正確。',
	'Login_Password' => '密碼',
	'Login_PasswordRepeat' => '密碼（再次輸入）',
	'Login_ChangePassword' => '變更密碼',
	'Login_LoginOrEmail' => '登入帳號或 E-mail',
	'Login_LogIn' => '登入',
	'Login_Logout' => '登出',
	'Login_LostYourPassword' => '遺失了您的密碼嗎？',
	'Login_PasswordsDoNotMatch' => '密碼並不相符！',
	'Login_InvalidUsernameEmail' => '無效的使用者名稱 和/或 E-mail 位址',
	'Login_InvalidOrExpiredToken' => '權杖不正確或已過期！',
	'Login_ContactAdmin' => '可能原因：您的伺服主機可能已經停用了 mail() 函式。<br />請聯絡您的 Piwik 管理員！',
	'Login_ExceptionPasswordMD5HashExpected' => '密碼參數會是一個 MD5 雜湊加密的密碼！',
	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => '超級使用者無法以 \'%s\' 機制通過身份驗證。',
	'Mobile_AnonymousAccess' => '匿名存取',
	'Mobile_AccessUrlLabel' => 'Piwik 存取網址',
	'Mobile_EnableGraphsLabel' => '顯示圖表',
	'Mobile_MultiChartLabel' => '顯示 sparklines',
	'Mobile_NetworkNotReachable' => '網路無法訪問',
	'Mobile_SaveSuccessError' => '請確認設定',
	'Mobile_YouAreOffline' => '抱歉，您目前為離線狀態',
	'MultiSites_PluginDescription' => '顯示多個網站的摘要 / 統計。目前為 Piwik 的核心外掛。',
	'MultiSites_Evolution' => '發展趨勢',
	'Provider_PluginDescription' => '訪客的網際網路服務供應商報表。',
	'Provider_WidgetProviders' => '網際網路服務供應商',
	'Provider_ColumnProvider' => '供應商',
	'Provider_SubmenuLocationsProvider' => '訪客分佈 & 網際網路服務供應商',
	'Referers_PluginDescription' => '推薦連結網站資料報表：搜尋引擎、關鍵字、網站、廣告活動追蹤及直接流量。',
	'Referers_Referers' => '推薦連結網站',
	'Referers_SearchEngines' => '搜尋引擎',
	'Referers_Keywords' => '關鍵字',
	'Referers_DirectEntry' => '直接流量',
	'Referers_Websites' => '網站',
	'Referers_Campaigns' => '廣告活動',
	'Referers_Evolution' => '此統計期的發展趨勢',
	'Referers_Type' => '推薦連結網站類型',
	'Referers_ColumnRefererType' => '推薦連結網站類型',
	'Referers_ColumnSearchEngine' => '搜尋引擎',
	'Referers_ColumnWebsite' => '網站',
	'Referers_ColumnWebsitePage' => '網站頁面',
	'Referers_ColumnKeyword' => '關鍵字',
	'Referers_ColumnCampaign' => '廣告活動',
	'Referers_DetailsByRefererType' => '推薦連結網站類型詳細資料',
	'Referers_TypeDirectEntries' => '%s 個來自直接流量',
	'Referers_TypeSearchEngines' => '%s 個來自搜尋引擎',
	'Referers_TypeWebsites' => '%s 個來自網站',
	'Referers_TypeCampaigns' => '%s 個來自廣告活動',
	'Referers_Distinct' => '推薦連結網站類型的不同參照項目',
	'Referers_DistinctSearchEngines' => '不同的搜尋引擎',
	'Referers_DistinctKeywords' => '不同的關鍵字',
	'Referers_DistinctCampaigns' => '不同的廣告活動',
	'Referers_DistinctWebsites' => '不同的網站',
	'Referers_UsingNDistinctUrls' => '(使用 %s 不同的網址)',
	'Referers_SubmenuSearchEngines' => '搜尋引擎 & 關鍵字',
	'Referers_SubmenuWebsites' => '網站',
	'Referers_SubmenuCampaigns' => '廣告活動',
	'Referers_WidgetKeywords' => '關鍵字清單',
	'Referers_WidgetCampaigns' => '廣告活動清單',
	'Referers_WidgetExternalWebsites' => '外部網站清單',
	'Referers_WidgetSearchEngines' => '最佳搜尋引擎',
	'Referers_WidgetOverview' => '總覽',
	'SecurityInfo_PluginDescription' => '基於 PhpSecInfo 從 PHP 安全協會，這個外掛提供安全性資訊，並提供你的PHP環境改善建議。它是一個多層次的安全工具。它不會從原始碼 / 應用程式來取代。',
	'SecurityInfo_Security' => '安全性',
	'SecurityInfo_SecurityInformation' => 'PHP 安全性資訊',
	'SecurityInfo_Test' => '測試',
	'SecurityInfo_Result' => '結果',
	'SEO_SeoRankings' => 'SEO 評比',
	'SEO_AlexaRank' => 'Alexa 排名',
	'SEO_DomainAge' => '網域名稱年齡',
	'SEO_Rank' => '評比',
	'SEO_Pages' => '頁面',
	'SEO_SEORankingsFor' => '%s 的 SEO 評比',
	'SitesManager_PluginDescription' => 'Piwik 網站管理：新增一個新網站、編輯一個已存在的網站、顯示插入你網頁的 JavaScript 原始碼。所有動作都可以透過 API 使用。',
	'SitesManager_Sites' => '網站',
	'SitesManager_TrackingTags' => '%s 的追蹤程式碼',
	'SitesManager_WebsitesManagement' => '網站管理',
	'SitesManager_MainDescription' => '你的網站分析報告需要網站！新增、更新、刪除網站，並顯示 JavaScript 追蹤程式碼以供插入在你的網頁之中。',
	'SitesManager_JsTrackingTag' => 'JavaScript 追蹤程式碼',
	'SitesManager_JsTrackingTagHelp' => '這是插入所有頁面的 JavaScript 追蹤原始碼',
	'SitesManager_ShowTrackingTag' => '顯示追蹤程式碼',
	'SitesManager_NoWebsites' => '你沒有任何網站可以管理。',
	'SitesManager_AddSite' => '增加一個新網站',
	'SitesManager_NotFound' => '找不到網站',
	'SitesManager_AliasUrlHelp' => '這是建議，但不是必須，定義一些你的訪客進入此網站時可能的網址，一行一個。網站的網址別名將不會顯示在推薦連結 > 網站報表裡。注意 Piwik 能兼顧包含及不包含 \'www\' 的網址。',
	'SitesManager_Urls' => 'URL 位址',
	'SitesManager_MenuSites' => '網站',
	'SitesManager_DeleteConfirm_js' => '你確定要刪除網站 %s 嗎？',
	'SitesManager_ExceptionDeleteSite' => '不可能刪除這個網站，因為它是唯一註冊的網站。請先增加新的網站，然後在刪除它。',
	'SitesManager_ExceptionNoUrl' => '你必須為此網站指定至少一個 URL 位址。',
	'SitesManager_ExceptionEmptyName' => '網站名稱不可為空。',
	'SitesManager_ExceptionInvalidUrl' => '此 URL 位址 \'%s\' 並非一個有效的 URL 位址。',
	'SitesManager_ExceptionInvalidTimezone' => '時區 "%s" 無效。請輸入正確的時區。',
	'SitesManager_ExceptionInvalidCurrency' => '貨幣 "%s" 無效。請輸入正確的貨幣符號（例如 %s）',
	'SitesManager_ExceptionInvalidIPFormat' => '欲排除的 IP "%s" 不符合有效的 IP 格式（例如 %s）。',
	'SitesManager_SuperUserCan' => '超級使用者也可以為新網站 %s 指定全域設定%s。',
	'SitesManager_ExcludedIps' => '排除 IP',
	'SitesManager_GlobalListExcludedIps' => '全域排除的 IP 列表',
	'SitesManager_ListOfIpsToBeExcludedOnAllWebsites' => '以下的 IP 位址將會被所有網站忽略。',
	'SitesManager_ExcludedParameters' => '排除參數',
	'SitesManager_GlobalListExcludedQueryParameters' => '全域排除的參數列表',
	'SitesManager_ListOfQueryParametersToBeExcludedOnAllWebsites' => '以下的網址查詢參數將會被所有網站忽略。',
	'SitesManager_ListOfQueryParametersToExclude' => '輸入網址查詢參數列表，一行一個，用來將特定網址排除在報告之外。',
	'SitesManager_PiwikWillAutomaticallyExcludeCommonSessionParameters' => 'Piwik 將會自動排除常見的會話參數 (%s)。',
	'SitesManager_HelpExcludedIps' => '輸入 IP 列表，一行一個，使 Piwik 不追蹤特定 IP 位址。你也可以使用萬用字元, 例如 %1$s 或 %2$s',
	'SitesManager_YourCurrentIpAddressIs' => '你目前的 IP 位址是 %s',
	'SitesManager_SelectACity' => '選擇一個城市',
	'SitesManager_ChooseCityInSameTimezoneAsYou' => '選擇一個與你目前時區相同的城市。',
	'SitesManager_ChangingYourTimezoneWillOnlyAffectDataForward' => '變更時區僅會影響往後的數據，不會溯及既往。',
	'SitesManager_AdvancedTimezoneSupportNotFound' => '在你的 PHP 找不到進階時區支援功能（PHP>=5.2 支援）。你還是可以手動選擇 UTC。',
	'SitesManager_UTCTimeIs' => 'UTC 時間是 %s.',
	'SitesManager_Timezone' => '時區',
	'SitesManager_GlobalWebsitesSettings' => '全域網站設定',
	'SitesManager_DefaultTimezoneForNewWebsites' => '新網站預設時區',
	'SitesManager_SelectDefaultTimezone' => '你可以為新的網站選擇預設的時區。',
	'SitesManager_Currency' => '貨幣',
	'SitesManager_CurrencySymbolWillBeUsedForGoals' => '貨幣符號旁將顯示目標收益。',
	'SitesManager_DefaultCurrencyForNewWebsites' => '新網站預設貨幣',
	'SitesManager_SelectDefaultCurrency' => '你可以為新的網站選擇預設的貨幣。',
	'TranslationsAdmin_PluginDescription' => '協助將 Piwik 翻譯為你所用的語言。',
	'TranslationsAdmin_MenuTranslations' => '翻譯',
	'TranslationsAdmin_MenuLanguages' => '語系',
	'TranslationsAdmin_LanguageCode' => '語系代碼',
	'TranslationsAdmin_Plugin' => '外掛程式',
	'TranslationsAdmin_Definition' => '定義',
	'TranslationsAdmin_DefaultString' => '預設字串 (英語)',
	'TranslationsAdmin_TranslationString' => '翻譯字串 (目前的語系: %s)',
	'TranslationsAdmin_Translations' => '翻譯',
	'TranslationsAdmin_FixPermissions' => '請修正檔案系統權限',
	'TranslationsAdmin_AddLanguage' => '增加語系',
	'TranslationsAdmin_Export' => '匯出語系',
	'TranslationsAdmin_Import' => '匯入語系',
	'UserCountry_PluginDescription' => '訪客的來源/國家報表。',
	'UserCountry_Country' => '國家',
	'UserCountry_Continent' => '世界大陸洲',
	'UserCountry_DistinctCountries' => '%s 個不同的國家',
	'UserCountry_Location' => '位置',
	'UserCountry_SubmenuLocations' => '所在地',
	'UserCountry_country_ac' => '英屬亞森松島',
	'UserCountry_country_ad' => '安道爾',
	'UserCountry_country_ae' => '阿拉伯聯合大公國',
	'UserCountry_country_af' => '阿富汗',
	'UserCountry_country_ag' => '安地卡及巴布達',
	'UserCountry_country_ai' => '英屬安圭拉島',
	'UserCountry_country_al' => '阿爾巴尼亞',
	'UserCountry_country_am' => '亞美尼亞',
	'UserCountry_country_an' => '荷屬安地列斯',
	'UserCountry_country_ao' => '安哥拉',
	'UserCountry_country_aq' => '南極洲',
	'UserCountry_country_ar' => '阿根廷',
	'UserCountry_country_as' => '美屬薩摩亞群島',
	'UserCountry_country_at' => '奧地利',
	'UserCountry_country_au' => '澳洲',
	'UserCountry_country_aw' => '阿魯巴島',
	'UserCountry_country_ax' => '奧蘭群島',
	'UserCountry_country_az' => '亞塞拜然',
	'UserCountry_country_ba' => '波士尼亞與赫塞哥維納',
	'UserCountry_country_bb' => '巴貝多',
	'UserCountry_country_bd' => '孟加拉',
	'UserCountry_country_be' => '比利時',
	'UserCountry_country_bf' => '布吉納法索',
	'UserCountry_country_bg' => '保加利亞',
	'UserCountry_country_bh' => '巴林',
	'UserCountry_country_bi' => '蒲隆地',
	'UserCountry_country_bj' => '貝南',
	'UserCountry_country_bl' => '法屬聖巴泰勒米島',
	'UserCountry_country_bm' => '百慕達群島',
	'UserCountry_country_bn' => '汶萊',
	'UserCountry_country_bo' => '波利維亞',
	'UserCountry_country_br' => '巴西',
	'UserCountry_country_bs' => '巴哈馬',
	'UserCountry_country_bt' => '不丹',
	'UserCountry_country_bu' => '緬甸',
	'UserCountry_country_bv' => '波維特島',
	'UserCountry_country_bw' => '波札那',
	'UserCountry_country_by' => '白俄羅斯',
	'UserCountry_country_bz' => '貝里斯',
	'UserCountry_country_ca' => '加拿大',
	'UserCountry_country_cc' => '可可斯群島',
	'UserCountry_country_cd' => '剛果民主主義共和國',
	'UserCountry_country_cf' => '中非共和國',
	'UserCountry_country_cg' => '剛果共和國',
	'UserCountry_country_ch' => '瑞士',
	'UserCountry_country_ci' => '象牙海岸',
	'UserCountry_country_ck' => '庫克群島',
	'UserCountry_country_cl' => '智利',
	'UserCountry_country_cm' => '喀麥隆',
	'UserCountry_country_cn' => '中國',
	'UserCountry_country_co' => '哥倫比亞',
	'UserCountry_country_cp' => '克利珀頓島',
	'UserCountry_country_cr' => '哥斯大黎加',
	'UserCountry_country_cs' => '塞爾維亞蒙特內哥羅',
	'UserCountry_country_cu' => '古巴',
	'UserCountry_country_cv' => '維德角共和國',
	'UserCountry_country_cx' => '聖誕島',
	'UserCountry_country_cy' => '賽普勒斯',
	'UserCountry_country_cz' => '捷克共和國',
	'UserCountry_country_de' => '德國',
	'UserCountry_country_dg' => '英屬迪亞哥加西亞島',
	'UserCountry_country_dj' => '吉布地',
	'UserCountry_country_dk' => '丹麥',
	'UserCountry_country_dm' => '多明尼克',
	'UserCountry_country_do' => '多明尼加共和國',
	'UserCountry_country_dz' => '阿爾及利亞',
	'UserCountry_country_ea' => '西屬北非休達與梅利利亞城',
	'UserCountry_country_ec' => '厄瓜多',
	'UserCountry_country_ee' => '愛沙尼亞',
	'UserCountry_country_eg' => '埃及',
	'UserCountry_country_eh' => '西撒哈拉',
	'UserCountry_country_er' => '厄立特里亞',
	'UserCountry_country_es' => '西班牙',
	'UserCountry_country_et' => '衣索比亞',
	'UserCountry_country_eu' => '歐盟',
	'UserCountry_country_fi' => '芬蘭',
	'UserCountry_country_fj' => '斐濟',
	'UserCountry_country_fk' => '福克蘭群島 (馬爾維納斯群島)',
	'UserCountry_country_fm' => '密克羅尼西亞聯邦',
	'UserCountry_country_fo' => '法羅群島',
	'UserCountry_country_fr' => '法國',
	'UserCountry_country_fx' => '法屬美特羅波利坦',
	'UserCountry_country_ga' => '加彭',
	'UserCountry_country_gb' => '大不列顛',
	'UserCountry_country_gd' => '格瑞納達',
	'UserCountry_country_ge' => '喬治亞',
	'UserCountry_country_gf' => '法屬圭亞那',
	'UserCountry_country_gg' => '根息島(根息乳牛島)',
	'UserCountry_country_gh' => '迦納',
	'UserCountry_country_gi' => '直布羅陀',
	'UserCountry_country_gl' => '格陵蘭',
	'UserCountry_country_gm' => '甘比亞',
	'UserCountry_country_gn' => '幾內亞',
	'UserCountry_country_gp' => '瓜德魯普島',
	'UserCountry_country_gq' => '赤道幾內亞',
	'UserCountry_country_gr' => '希臘',
	'UserCountry_country_gs' => '南喬治亞及南桑威奇群島',
	'UserCountry_country_gt' => '瓜地馬拉',
	'UserCountry_country_gu' => '關島',
	'UserCountry_country_gw' => '幾內亞比索',
	'UserCountry_country_gy' => '圭亞那',
	'UserCountry_country_hk' => '香港',
	'UserCountry_country_hm' => '赫德及麥當勞群島',
	'UserCountry_country_hn' => '宏都拉斯',
	'UserCountry_country_hr' => '克羅埃西亞',
	'UserCountry_country_ht' => '海地',
	'UserCountry_country_hu' => '匈牙利',
	'UserCountry_country_ic' => '西屬加那利群島自治區',
	'UserCountry_country_id' => '印尼',
	'UserCountry_country_ie' => '愛爾蘭',
	'UserCountry_country_il' => '以色列',
	'UserCountry_country_im' => '曼島',
	'UserCountry_country_in' => '印度',
	'UserCountry_country_io' => '英屬印度洋領地(不列顛群島)',
	'UserCountry_country_iq' => '伊拉克',
	'UserCountry_country_ir' => '伊朗',
	'UserCountry_country_is' => '冰島',
	'UserCountry_country_it' => '義大利',
	'UserCountry_country_je' => '澤西島',
	'UserCountry_country_jm' => '牙買加',
	'UserCountry_country_jo' => '約旦',
	'UserCountry_country_jp' => '日本',
	'UserCountry_country_ke' => '肯亞',
	'UserCountry_country_kg' => '吉爾吉斯斯坦',
	'UserCountry_country_kh' => '柬埔寨',
	'UserCountry_country_ki' => '吉里巴斯',
	'UserCountry_country_km' => '科摩洛',
	'UserCountry_country_kn' => '聖克里斯多福及尼維斯群島',
	'UserCountry_country_kp' => '北韓',
	'UserCountry_country_kr' => '南韓',
	'UserCountry_country_kw' => '科威特',
	'UserCountry_country_ky' => '開曼群島',
	'UserCountry_country_kz' => '哈薩克',
	'UserCountry_country_la' => '寮國',
	'UserCountry_country_lb' => '黎巴嫩',
	'UserCountry_country_lc' => '聖路西亞島',
	'UserCountry_country_li' => '列支敦斯登',
	'UserCountry_country_lk' => '斯里蘭卡',
	'UserCountry_country_lr' => '賴比瑞亞',
	'UserCountry_country_ls' => '賴索托',
	'UserCountry_country_lt' => '立陶宛',
	'UserCountry_country_lu' => '盧森堡',
	'UserCountry_country_lv' => '拉脫維亞',
	'UserCountry_country_ly' => '利比亞',
	'UserCountry_country_ma' => '摩洛哥',
	'UserCountry_country_mc' => '摩納哥',
	'UserCountry_country_md' => '摩爾多瓦共和國',
	'UserCountry_country_me' => '蒙特內哥羅',
	'UserCountry_country_mf' => '聖馬丁',
	'UserCountry_country_mg' => '馬達加斯加',
	'UserCountry_country_mh' => '馬紹爾群島',
	'UserCountry_country_mk' => '馬其頓',
	'UserCountry_country_ml' => '馬利',
	'UserCountry_country_mm' => '緬甸',
	'UserCountry_country_mn' => '蒙古國',
	'UserCountry_country_mo' => '澳門',
	'UserCountry_country_mp' => '北馬里亞納群島',
	'UserCountry_country_mq' => '法屬馬丁尼克島',
	'UserCountry_country_mr' => '茅利塔尼亞伊斯蘭共和國',
	'UserCountry_country_ms' => '蒙特色納島',
	'UserCountry_country_mt' => '馬爾他',
	'UserCountry_country_mu' => '模里西斯',
	'UserCountry_country_mv' => '馬爾地夫',
	'UserCountry_country_mw' => '馬拉威',
	'UserCountry_country_mx' => '墨西哥',
	'UserCountry_country_my' => '馬來西亞',
	'UserCountry_country_mz' => '莫三比克',
	'UserCountry_country_na' => '納米比亞',
	'UserCountry_country_nc' => '新喀里多尼亞',
	'UserCountry_country_ne' => '尼日',
	'UserCountry_country_nf' => '諾福克島',
	'UserCountry_country_ng' => '奈及利亞',
	'UserCountry_country_ni' => '尼加拉瓜',
	'UserCountry_country_nl' => '荷蘭',
	'UserCountry_country_no' => '挪威',
	'UserCountry_country_np' => '尼泊爾',
	'UserCountry_country_nr' => '諾魯',
	'UserCountry_country_nt' => '中立區',
	'UserCountry_country_nu' => '紐埃島',
	'UserCountry_country_nz' => '紐西蘭',
	'UserCountry_country_om' => '阿曼',
	'UserCountry_country_pa' => '巴拿馬',
	'UserCountry_country_pe' => '秘魯',
	'UserCountry_country_pf' => '法屬玻里尼西亞',
	'UserCountry_country_pg' => '巴布亞紐幾內亞',
	'UserCountry_country_ph' => '菲律賓',
	'UserCountry_country_pk' => '巴基斯坦',
	'UserCountry_country_pl' => '波蘭',
	'UserCountry_country_pm' => '法屬聖皮埃爾密克隆群島',
	'UserCountry_country_pn' => '英屬匹特開恩島',
	'UserCountry_country_pr' => '波多黎各',
	'UserCountry_country_ps' => '巴勒斯坦',
	'UserCountry_country_pt' => '葡萄牙',
	'UserCountry_country_pw' => '帛琉',
	'UserCountry_country_py' => '巴拉圭',
	'UserCountry_country_qa' => '卡達',
	'UserCountry_country_re' => '法屬留尼旺島',
	'UserCountry_country_ro' => '羅馬尼亞',
	'UserCountry_country_rs' => '塞爾維亞',
	'UserCountry_country_ru' => '俄羅斯',
	'UserCountry_country_rw' => '盧安達',
	'UserCountry_country_sa' => '沙烏地阿拉伯',
	'UserCountry_country_sb' => '索羅門群島',
	'UserCountry_country_sc' => '塞席爾群島',
	'UserCountry_country_sd' => '蘇丹',
	'UserCountry_country_se' => '瑞典',
	'UserCountry_country_sf' => '芬蘭',
	'UserCountry_country_sg' => '新加坡',
	'UserCountry_country_sh' => '英屬聖赫勒拿島',
	'UserCountry_country_si' => '斯洛維尼亞',
	'UserCountry_country_sj' => '冷岸群島(斯瓦爾巴和揚馬延群島)',
	'UserCountry_country_sk' => '斯洛伐克',
	'UserCountry_country_sl' => '獅子山共和國',
	'UserCountry_country_sm' => '聖馬利諾',
	'UserCountry_country_sn' => '塞內加爾',
	'UserCountry_country_so' => '索馬利亞',
	'UserCountry_country_sr' => '蘇利南',
	'UserCountry_country_st' => '聖多美普林西比',
	'UserCountry_country_su' => '舊蘇聯',
	'UserCountry_country_sv' => '薩爾瓦多',
	'UserCountry_country_sy' => '敘利亞',
	'UserCountry_country_sz' => '史瓦濟蘭',
	'UserCountry_country_ta' => '英屬特里斯坦達庫尼亞群島',
	'UserCountry_country_tc' => '土克斯及開科斯群島',
	'UserCountry_country_td' => '查德',
	'UserCountry_country_tf' => '法屬南極領地',
	'UserCountry_country_tg' => '多哥',
	'UserCountry_country_th' => '泰國',
	'UserCountry_country_tj' => '塔吉克',
	'UserCountry_country_tk' => '托克勞群島',
	'UserCountry_country_tl' => '東帝汶',
	'UserCountry_country_tm' => '土庫曼',
	'UserCountry_country_tn' => '突尼西亞',
	'UserCountry_country_to' => '東加王國',
	'UserCountry_country_tp' => '東帝汶',
	'UserCountry_country_tr' => '土耳其',
	'UserCountry_country_tt' => '千里達托貝哥',
	'UserCountry_country_tv' => '吐瓦魯',
	'UserCountry_country_tw' => '台灣共和國',
	'UserCountry_country_tz' => '坦尚尼亞',
	'UserCountry_country_ua' => '烏克蘭',
	'UserCountry_country_ug' => '烏干達',
	'UserCountry_country_uk' => '英國',
	'UserCountry_country_um' => '美屬澳特蘭群島',
	'UserCountry_country_us' => '美國',
	'UserCountry_country_uy' => '烏拉圭',
	'UserCountry_country_uz' => '烏茲別克斯坦',
	'UserCountry_country_va' => '梵諦岡',
	'UserCountry_country_vc' => '聖文森',
	'UserCountry_country_ve' => '委內瑞拉',
	'UserCountry_country_vg' => '英屬維京群島',
	'UserCountry_country_vi' => '美屬維京群島',
	'UserCountry_country_vn' => '越南',
	'UserCountry_country_vu' => '萬那杜',
	'UserCountry_country_wf' => '瓦利斯富圖納群島',
	'UserCountry_country_ws' => '西薩摩亞',
	'UserCountry_country_ye' => '葉門',
	'UserCountry_country_yt' => '馬約特島',
	'UserCountry_country_yu' => '南斯拉夫',
	'UserCountry_country_za' => '南非',
	'UserCountry_country_zm' => '尚比亞',
	'UserCountry_country_zr' => '薩伊',
	'UserCountry_country_zw' => '辛巴威',
	'UserCountry_continent_eur' => '歐洲',
	'UserCountry_continent_afr' => '非洲',
	'UserCountry_continent_asi' => '亞洲',
	'UserCountry_continent_amn' => '北美洲',
	'UserCountry_continent_ams' => '中南美洲',
	'UserCountry_continent_oce' => '大洋洲',
	'UserCountryMap_map' => '地圖',
	'UserCountryMap_worldMap' => '世界地圖',
	'UserCountryMap_toggleFullscreen' => '切換全螢幕',
	'UserSettings_PluginDescription' => '各個用戶設定報表：瀏覽器、瀏覽器家族、作業系統、外掛、解析度、全域設定。',
	'UserSettings_VisitorSettings' => '造訪者設定值',
	'UserSettings_BrowserFamilies' => '瀏覽器家族',
	'UserSettings_Browsers' => '使用瀏覽器',
	'UserSettings_Plugins' => '瀏覽器外掛',
	'UserSettings_Configurations' => '客戶端配置',
	'UserSettings_OperatingSystems' => '作業系統',
	'UserSettings_Resolutions' => '解析度',
	'UserSettings_WideScreen' => '寬螢幕',
	'UserSettings_ColumnBrowserFamily' => '瀏覽器家族',
	'UserSettings_ColumnBrowser' => '瀏覽器',
	'UserSettings_ColumnPlugin' => '外掛',
	'UserSettings_ColumnConfiguration' => '客戶端配置',
	'UserSettings_ColumnOperatingSystem' => '作業系統',
	'UserSettings_ColumnResolution' => '解析度',
	'UserSettings_ColumnTypeOfScreen' => '螢幕類型',
	'UserSettings_WidgetResolutions' => '畫面解析度',
	'UserSettings_WidgetBrowsers' => '使用瀏覽器',
	'UserSettings_WidgetPlugins' => '瀏覽器外掛清單',
	'UserSettings_PluginDetectionDoesNotWorkInIE' => '注意：外掛偵測無法在 Internet Explorer 上運作。這個報告僅提供非 IE 瀏覽器。',
	'UserSettings_WidgetWidescreen' => '傳統螢幕 / 寬螢幕',
	'UserSettings_WidgetBrowserFamilies' => '瀏覽器依家族分',
	'UserSettings_WidgetOperatingSystems' => '作業系統',
	'UserSettings_WidgetGlobalVisitors' => '全域訪客配置',
	'UserSettings_SubmenuSettings' => '環境設定值',
	'UsersManager_PluginDescription' => 'Piwik 使用者管理：新增一個新使用者、編輯已存在的使用者或更新權限。所有動作也可以透過 API 進行。',
	'UsersManager_UsersManagement' => '使用者管理',
	'UsersManager_UsersManagementMainDescription' => '建立新使用者或更新現存的使用者。然後你就可以將他們設定為以上權限。',
	'UsersManager_ManageAccess' => '管理權限',
	'UsersManager_MainDescription' => '決定在你網站上的哪個使用者具有何種 Piwik 存取權。 你也可以一次設定所有網站的權限。',
	'UsersManager_Sites' => '網站',
	'UsersManager_AllWebsites' => '所有網站',
	'UsersManager_ApplyToAllWebsites' => '套用至所有網站',
	'UsersManager_User' => '使用者',
	'UsersManager_PrivNone' => '無存取權限',
	'UsersManager_PrivView' => '檢視',
	'UsersManager_PrivAdmin' => '管理員',
	'UsersManager_ChangeAllConfirm' => '你確定要在所有網站上變更 \'%s\' 的權限嗎？',
	'UsersManager_Password' => '密碼',
	'UsersManager_Email' => 'E-mail',
	'UsersManager_Alias' => '別名',
	'UsersManager_TheSuperUserAliasCannotBeChanged' => '超級使用者的別名無法變更。',
	'UsersManager_ReportToLoadByDefault' => '預設載入報表',
	'UsersManager_ReportDateToLoadByDefault' => '預設載入日期',
	'UsersManager_ForAnonymousUsersReportDateToLoadByDefault' => '對於匿名用戶預設載入日期',
	'UsersManager_ExcludeVisitsViaCookie' => '以 cookie 排除你的訪問紀錄',
	'UsersManager_YourVisitsAreIgnoredOnDomain' => '%s你的訪問紀錄已在 %s %s 被 Piwik 忽略（在你的瀏覽器找到 Piwik 拒絕 cookie）',
	'UsersManager_YourVisitsAreNotIgnored' => '%s你的訪問紀錄沒有被 Piwik 忽略%s（在你的瀏覽器找不到 Piwik 拒絕 cookie）',
	'UsersManager_ClickHereToDeleteTheCookie' => '點擊這裡刪除 cookie 並讓 Piwik 追蹤你的訪問紀錄',
	'UsersManager_ClickHereToSetTheCookieOnDomain' => '點擊這裡設定一個 cookie 讓 %s 的 Piwik 排除你的訪問紀錄',
	'UsersManager_Edit' => '編輯',
	'UsersManager_AddUser' => '新增一個使用者',
	'UsersManager_MenuUsers' => '使用者',
	'UsersManager_MenuUserSettings' => '使用者設定',
	'UsersManager_MenuAnonymousUserSettings' => '匿名用戶設定',
	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => '當使用者未登入且訪問 Piwik 時，他們應該前往',
	'UsersManager_ChangePassword' => '變更密碼',
	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => '如果你要變更密碼時請輸入新的密碼。否則留空。',
	'UsersManager_TypeYourPasswordAgain' => '再輸入一次新的密碼。',
	'UsersManager_TheLoginScreen' => '登入畫面',
	'UsersManager_DeleteConfirm_js' => '你確定要刪除使用者 %s 嗎？',
	'UsersManager_YourUsernameCannotBeChanged' => '你的使用者名稱無法變更。',
	'UsersManager_ExceptionLoginExists' => '登入帳號 \'%s\' 已經存在。',
	'UsersManager_ExceptionEmailExists' => '使用 \'%s\' E-mail 的使用者已經存在。',
	'UsersManager_ExceptionInvalidLoginFormat' => '登入帳號的長度必須介於 %1$s 至 %2$s 字元之間，並且只能包含字母、數字或字元 \'_\' 或 \'-\' 或 \'.\' 。',
	'UsersManager_ExceptionInvalidEmail' => '此 E-mail 地址格式無效。',
	'UsersManager_ExceptionDeleteDoesNotExist' => '使用者 \'%s\' 並不存在，所以無法刪除它。',
	'UsersManager_ExceptionAdminAnonymous' => '你不能把\'管理員\'存取權限給匿名用戶。',
	'UsersManager_ExceptionEditAnonymous' => '匿名用戶不能修改或刪除。因為 Piwik 用來定義一個還未登入的使用者。舉例來說，你可以把\'檢視\'權限給匿名用戶來公開你的統計資料。',
	'UsersManager_ExceptionSuperUser' => '請求的使用者為超級使用者且無法被查詢，請透過應用程式介面 API 編輯或刪除。 你可以在你的 Piwik 設定檔手動編輯超級使用者。',
	'UsersManager_ExceptionUserDoesNotExist' => '使用者 \'%s\' 不存在。',
	'UsersManager_ExceptionAccessValues' => '參數存取必須有一個以下的值： [ %s ]',
	'UsersManager_ExceptionPasswordMD5HashExpected' => 'UsersManager.getTokenAuth 是以MD5加密的密碼（32個字元字串）。在使用此方法前請先呼叫 md5() 函式。',
	'VisitFrequency_PluginDescription' => '關於回訪者與一般訪客的報表。',
	'VisitFrequency_Evolution' => '此統計期的發展趨勢',
	'VisitFrequency_ColumnReturningVisits' => '重返造訪',
	'VisitFrequency_ColumnActionsByReturningVisits' => '重返造訪的活動數',
	'VisitFrequency_ColumnAverageVisitDurationForReturningVisitors' => '重返造訪的平均訪問時間（以秒為單位）',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => '重返造訪的跳出率',
	'VisitFrequency_ColumnAvgActionsPerReturningVisit' => '每個重返造訪的平均活動數',
	'VisitFrequency_ReturnVisits' => '%s 個重返造訪數',
	'VisitFrequency_ReturnActions' => '%s 個活動數由重返造訪所產生',
	'VisitFrequency_ReturnAvgActions' => '%s 個活動數每個重返造訪',
	'VisitFrequency_ReturnAverageVisitDuration' => '%s 重返造訪的平均訪問時間',
	'VisitFrequency_ReturnBounceRate' => '%s 個重返造訪離開率（於瀏覽單一網頁後離開網站）',
	'VisitFrequency_WidgetOverview' => '造訪頻率總覽',
	'VisitFrequency_WidgetGraphReturning' => '重返造訪圖表',
	'VisitFrequency_SubmenuFrequency' => '造訪頻率',
	'VisitorGenerator_PluginDescription' => '這個外掛用於建立假的訪客。這可以讓 Piwik 使用者或開發人員輕鬆產生假的資料來填充 Piwik 報表。',
	'VisitorGenerator_VisitorGenerator' => '訪客產生器',
	'VisitorGenerator_Warning' => '你將產生的假訪客將會記錄在你的 Piwik 資料庫裡。',
	'VisitorGenerator_NotReversible' => '它可能%s無法%s簡單地從 piwik 記錄中刪除。',
	'VisitorGenerator_AreYouSure' => '你確定要產生假的訪客嗎？',
	'VisitorGenerator_ChoiceYes' => '是，我確定！',
	'VisitorGenerator_Submit' => '送出',
	'VisitorGenerator_SelectWebsite' => '選擇網站',
	'VisitorGenerator_NbRequestsPerSec' => '每秒請求數',
	'VisitorGenerator_DaysToCompute' => '計算天數',
	'VisitorInterest_PluginDescription' => '關於訪客興趣的報表：頁面瀏覽次數、及花多少時間在網站裡。',
	'VisitorInterest_VisitsPerDuration' => '各個造訪停留時間的造訪次數',
	'VisitorInterest_VisitsPerNbOfPages' => '各個瀏覽頁面數的造訪次數',
	'VisitorInterest_ColumnVisitDuration' => '造訪停留時間',
	'VisitorInterest_ColumnPagesPerVisit' => '每次造訪瀏覽的頁面數',
	'VisitorInterest_WidgetLengths' => '訪客停留時間',
	'VisitorInterest_WidgetPages' => '每次造訪瀏覽的頁面數',
	'VisitorInterest_Engagement' => '忠誠度',
	'VisitorInterest_PlusXMin' => '%s 分',
	'VisitorInterest_BetweenXYMinutes' => '%1$s-%2$s 分',
	'VisitorInterest_OnePage' => '1 頁',
	'VisitorInterest_NPages' => '%s 頁',
	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$s 秒',
	'VisitsSummary_PluginDescription' => '一般分析項目報告：造訪次數、絕對不重複訪客、活動數、跳出率等等。',
	'VisitsSummary_VisitsSummary' => '訪客總覽',
	'VisitsSummary_NbVisits' => '%s 個造訪次數',
	'VisitsSummary_NbUniqueVisitors' => '%s 個絕對不重複訪客',
	'VisitsSummary_NbActionsDescription' => '%s 個活動（檢視網頁、下載和離開連結）',
	'VisitsSummary_AverageVisitDuration' => '%s 平均訪問時間',
	'VisitsSummary_MaxNbActions' => '%s 由單一次造訪所產生的最大活動數',
	'VisitsSummary_NbActionsPerVisit' => '%s 每個訪客的活動數',
	'VisitsSummary_NbVisitsBounced' => '%s 跳出率（於瀏覽單一網頁後離開網站）',
	'VisitsSummary_GenerateTime' => '頁面生成時間： %s 秒',
	'VisitsSummary_GenerateQueries' => '%s 個查詢已執行',
	'VisitsSummary_WidgetLastVisits' => '最近造訪圖表',
	'VisitsSummary_WidgetVisits' => '造訪次數總覽',
	'VisitsSummary_WidgetLastVisitors' => '最近獨立非重返訪客圖表',
	'VisitsSummary_WidgetOverviewGraph' => '圖表總覽',
	'VisitsSummary_SubmenuOverview' => '總覽',
	'VisitTime_PluginDescription' => '當地時段及伺服器時段報表。伺服器時段能作為排定網站維護時間的參考。',
	'VisitTime_LocalTime' => '依訪客端時段記錄的造訪次數',
	'VisitTime_ServerTime' => '依伺服器時段記錄的造訪次數',
	'VisitTime_ColumnServerTime' => '伺服器時段',
	'VisitTime_ColumnLocalTime' => '訪客端時段',
	'VisitTime_WidgetLocalTime' => '依訪客端時段記錄的造訪次數',
	'VisitTime_WidgetServerTime' => '依伺服器時段記錄的造訪次數',
	'VisitTime_SubmenuTimes' => '造訪時段',
	'VisitTime_NHour' => '%s 時',
	'Widgetize_PluginDescription' => '這個外掛讓你輕鬆輸出任何 Piwik 模組至你的網誌、網站或 iGoogle 及 Netvibes!',
	'PDFReports_EmailReports' => '郵寄報表',
	'PDFReports_SendReportNow' => '立即寄送報表',
	'PDFReports_EmailSchedule' => '郵寄排程',
	'PDFReports_SendReportTo' => '寄送報表至',
	'PDFReports_SentToMe' => '寄給我自己',
	'PDFReports_WeeklyScheduleHelp' => '每週排程：報表將會在每週的星期一寄出！',
	'PDFReports_MonthlyScheduleHelp' => '每月排程：報表將會在每月的第一天寄出！',
	'PDFReports_AlsoSendReportToTheseEmails' => '也將報表寄到這些電子郵件地址（一行一個信箱）：',
	'PDFReports_PiwikReports' => 'Piwik 報表',
	'PDFReports_EmailHello' => '您好，',
	'PDFReports_PleaseFindAttachedFile' => '請找到為了 %2$s 您的報表 %1$s 的附件檔！',
);
